<?php
  
  namespace Api\Controllers\Auth;
  
  use Api\Core\Controller;
  use PDO;
  
  class RegisterController extends Controller
  {
    public function register()
    {
      validate([
        'email' => 'required|email',
        'username' => 'required',
        'password' => 'required|min:4',
	      'ip' => 'required'
      ]);
	    
	    if (!validate_username(input("username"))) {
		    api()->error('INVALID_USERNAME', 'Invalid username!');
	    }
	    
	    $usernameValid = db()->prepare("SELECT COUNT(id) FROM Accounts WHERE username = ?");
	    $usernameValid->execute(array(input("username")));
	    $usernameCount = $usernameValid->fetchColumn();
      if ($usernameCount > 0) {
        api()->error('USERNAME_ALREADY_EXIST', 'Username already exists!', 409);
      }
	    
	    $emailValid = db()->prepare("SELECT COUNT(id) FROM Accounts WHERE email = ?");
	    $emailValid->execute(array(input("email")));
	    $emailCount = $emailValid->fetchColumn();
      if ($emailCount > 0) {
        api()->error('EMAIL_ALREADY_EXIST', 'Email already exists!', 409);
      }
			
      if (settings("registerLimit") != -1) {
	      $ipCount = db()->prepare("SELECT COUNT(id) FROM Accounts WHERE creationIP = ?");
	      $ipCount->execute(array(input("ip")));
	      $ipCount = $ipCount->fetchColumn();
	      
	      if ($ipCount >= (int)settings("registerLimit")) {
          api()->error('REGISTER_LIMIT', 'You have reached the limit of registrations!', 403);
	      }
      }
      
      $loginToken = md5(uniqid(mt_rand(), true));
      $password = createPassword(settings("passwordType"), input("password"));
      
      $insertAccounts = db()->prepare("INSERT INTO Accounts (username, realname, email, password, isVerified, creationIP, creationDate) VALUES (?, ?, ?, ?, ?, ?, ?)");
      $insertAccounts->execute(array(strtolower(input("username")), input("username"), input("email"), $password, (!moduleIsDisabled("email_verification") ? "0" : "1"), input("ip"), date("Y-m-d H:i:s")));
      $userID = db()->lastInsertId();
      $insertAccountSessions = db()->prepare("INSERT INTO AccountSessions (accountID, loginToken, creationIP, expiryDate, creationDate) VALUES (?, ?, ?, ?, ?)");
      $insertAccountSessions->execute(array($userID, $loginToken, input("ip"), createDuration(0.01666666666), date("Y-m-d H:i:s")));
			
			api()->success([
				'token' => $loginToken
			]);
    }
  }