<?php
  
  namespace Api\Controllers\Store;
  
  use Api\Core\Controller;
  use Api\Services\CurrencyService;
  use Api\Services\ListingService;
  use Api\Services\UserService;
  use PDO;

  class ListingController extends Controller
  {
    public function index()
    {
	    $user = UserService::getByUsername(_get('username'));
	    
	    $purchasedProductsIDs = [];
	    if ($user) {
		    $purchasedProductsIDs = db()->prepare("SELECT productID FROM PurchasedProducts WHERE accountID = ? AND (expiresAt > ? OR expiresAt IS NULL)");
		    $purchasedProductsIDs->execute(array($user["id"], date('Y-m-d H:i:s')));
		    $purchasedProductsIDs = $purchasedProductsIDs->fetchAll(PDO::FETCH_COLUMN);
	    }
			
      $categories = db()->prepare("SELECT * FROM ProductCategories WHERE isActive = ? ORDER BY priority DESC");
      $categories->execute([1]);
      $categories = $categories->fetchAll(PDO::FETCH_ASSOC);
			
			$filteredCategories = [];
	    
	    foreach ($categories as $category) {
		    $categoryRequiredProducts = db()->prepare("SELECT productID FROM ProductCategoryRequiredProducts WHERE categoryID = ?");
		    $categoryRequiredProducts->execute([$category["id"]]);
		    $categoryRequiredProducts = $categoryRequiredProducts->fetchAll(PDO::FETCH_COLUMN);
				
				if (count($categoryRequiredProducts) > 0 && empty(array_intersect($purchasedProductsIDs, $categoryRequiredProducts))) {
					continue;
				}
				
				$filteredCategories[] = $category;
	    }

      $products = db()->prepare("SELECT * FROM Products WHERE isActive = ? ORDER BY priority DESC");
      $products->execute([1]);
      $products = $products->fetchAll(PDO::FETCH_ASSOC);

      $currency = CurrencyService::get();

      $discountProducts = explode(",", settings('storeDiscountProducts'));
      for ($i = 0; $i < count($products); $i++) {
        $product = &$products[$i];
        $storeDiscountStatus = (settings('storeDiscount') != 0 && (in_array($product["id"], $discountProducts) || settings('storeDiscountProducts') == '0') && (settings('storeDiscountExpiryDate') > date("Y-m-d H:i:s") || settings('storeDiscountExpiryDate') == '1000-01-01 00:00:00'));
        if ($storeDiscountStatus)
          $product["discountedPrice"] = ($product['price'] * (100 - settings('storeDiscount'))) / 100;

        $product["priceText"] = money($product["price"], $currency);
        $product["discountedPriceText"] = money($product["discountedPrice"], $currency);
	      if (settings('tax') > 0 && settings('isCreditRequiredOnPurchase') == 0) {
		      $product["priceText"] *= (1 + settings('tax') / 100);
					$product["discountedPriceText"] *= (1 + settings('tax') / 100);
	      }
				
				// Custom Variables
	      $variables = db()->prepare("SELECT V.* FROM ProductVariables PV INNER JOIN StoreVariables V ON PV.variableID = V.id WHERE PV.productID = ?");
	      $variables->execute(array($product["id"]));
	      $product["variables"] = array_map(function ($variable) {
		      $variable["options"] = [];
		      if ($variable["type"] == "dropdown") {
			      $dropdownOptions = db()->prepare("SELECT * FROM StoreVariableDropdownOptions WHERE variableID = ?");
			      $dropdownOptions->execute(array($variable["id"]));
			      $variable["options"] = $dropdownOptions->fetchAll(PDO::FETCH_ASSOC);
		      }
		      
		      return $variable;
	      }, $variables->fetchAll(PDO::FETCH_ASSOC));
      }

      $tree = ListingService::buildTree($filteredCategories, $products);

      response()->json([
        'categories' => $tree
      ]);
    }
  }