<?php

namespace Dashboard\Controllers\Settings;

use Curl\Curl;
use Dashboard\Core\Controller;
use Dashboard\Core\Redirect;

class DiscordBotController extends Controller
{
    public function __construct()
    {
        abort_perm('MANAGE_SETTINGS');
    }

    public function index()
    {
			$isLinked = settings('discordBotLinkToken') != '' && settings('discordBotSettingsGuildID') != '';
      return view('settings.discord-bot.index', compact('isLinked'));
    }
	
		public function link()
		{
			if (settings('discordBotLinkToken') != '' && settings('discordBotSettingsGuildID') != '') {
				return back()->flash("error", t__('Discord Bot is already connected!'));
			}
			
			$token = settings('discordBotLinkToken');
			if ($token == '') {
				$curl = new Curl();
				$curl->post("https://discord-bot-api.leaderos.net/create-token", [
					"apiKey"   => settings('apiKey'),
					"server" => LOCATION,
				]);
				$response = json_decode($curl->response);
				if ($curl->error || !isset($response->data->token)) {
					if (isset($response->error) && $response->error == 'INVALID_API_KEY') {
						return back()->flash("error", t__('Invalid API Key! Please reset your API Key from Dashboard > Settings > API.'));
					}
					return back()->flash("error", t__('An error occurred while connecting to the Discord server. Please try again later.'));
				}
				$token = $response->data->token;
				updateSetting('discordBotLinkToken', $token);
			}
			$inviteLink = "https://discord-bot-api.leaderos.net/invite";
			
			return view('settings.discord-bot.link', compact('token', 'inviteLink'));
		}
		
		public function validate()
		{
			$curl = new Curl();
			$curl->post("https://discord-bot-api.leaderos.net/validate-token", [
				"token"   => settings('discordBotLinkToken'),
			]);
			$response = json_decode($curl->response);
			if ($curl->error || !isset($response->status)) {
				return back()->flash("error", t__('An error occurred while connecting to the Discord server. Please try again later.'));
			}
			if (!$response->status && $response->error == 'INVALID_TOKEN') {
				return back()->flash("error", t__('An error occurred while connecting to the Discord server. Please try again later.'));
			}
			if (!$response->status && $response->error == 'NOT_LINKED') {
				return back()->flash("error", t__('The Discord Bot is not linked to a server. Please follow the steps to link the bot to your Discord server!'));
			}
			$guildID = $response->data->guildID;
			updateSetting('discordBotSettingsGuildID', $guildID);
			
			$redirect = new Redirect(url('dashboard.settings.discord-bot.index'));
			return $redirect->flash("success", t__('Discord Bot has been successfully connected!'));
		}

    public function update()
    {
        foreach ($_POST as $key => $value) {
            $updateSettings = db()->prepare("UPDATE Settings SET value = ? WHERE name = ?");
            $updateSettings->execute([$value, $key]);
        }

        $updateSettings = db()->prepare("UPDATE Settings SET value = ? WHERE name = ?");
        $updateSettings->execute(array(time(), "updatedAt"));
        createLog("DISCORD_SETTINGS_UPDATED");
	    
		    $curl = new Curl();
		    $curl->post("https://discord-bot-api.leaderos.net/update-settings", [
			    "token"   => settings('discordBotLinkToken'),
			    "syncNames" => post('discordBotSettingsSyncNames'),
		    ]);
		    $response = json_decode($curl->response);
		    if ($curl->error || !isset($response->status) || !$response->status) {
			    return back()->flash("error", t__('An error occurred while updating the Discord settings. Please try again later.'));
		    }

        return back()->flash("success", t__('Changes has been saved successfully!'));
    }
	
		public function reset()
		{
			$token = settings('discordBotLinkToken');
			updateSettings([
				'discordBotLinkToken' => '',
				'discordBotSettingsGuildID' => '',
				'discordBotSettingsSyncNames' => '0',
			]);
			
			$curl = new Curl();
			$curl->post("https://discord-bot-api.leaderos.net/reset-bot", [
				"token" => $token,
			]);
			$response = json_decode($curl->response);
			if ($curl->error || !isset($response->status) || !$response->status) {
				response()->json([
					'status' => false,
					'message' => t__('An error occurred while updating the Discord settings. Please try again later.')
				]);
			}
			
			response()->json([
				'status' => true
			]);
		}
}