<?php

namespace Dashboard\Controllers\Settings;

use Dashboard\Core\Controller;
use Dashboard\Core\Redirect;
use Dashboard\Libs\Parasut;

class ParasutController extends Controller
{
    public function __construct()
    {
        abort_perm('MANAGE_SETTINGS');
    }

    public function index()
    {
        return view('settings.parasut.index');
    }

    public function update()
    {
        foreach ($_POST as $key => $value) {
            $updateSettings = db()->prepare("UPDATE Settings SET value = ? WHERE name = ?");
            $updateSettings->execute([$value, $key]);
        }

        $updateSettings = db()->prepare("UPDATE Settings SET value = ? WHERE name = ?");
        $updateSettings->execute(array(time(), "updatedAt"));
        createLog("PARASUT_SETTINGS_UPDATED");

        redirect(url('dashboard.settings.parasut.oauth'));
    }

    public function oauth()
    {
      if (settings('parasutAuthType') == 1) {
        $parasut = new Parasut(settings('parasutClientID'), settings('parasutClientSecret'), settings('parasutCompanyID'));

        $accessTokenResponse = $parasut->getAccessTokenWithPassword(settings('parasutUsername'), settings('parasutPassword'));
        $accessToken = $accessTokenResponse->access_token;
        $refreshToken = $accessTokenResponse->refresh_token;
        $expiresIn = $accessTokenResponse->expires_in;

        //$createProduct = $parasut->createProduct($accessToken, "Dijital Ürün");
        //$productID = $createProduct->data->id;

        updateSettings([
          "parasutAccessToken" => $accessToken,
          "parasutRefreshToken" => $refreshToken,
          "parasutTokenExpiryDate" => date('Y-m-d H:i:s', time() + $expiresIn),
	        //'parasutProductID' => $productID,
        ]);

        $redirect = new Redirect(url('dashboard.settings.parasut.index'));
        return $redirect->flash("success", t__('Changes has been saved successfully!'));
      } else {
        $redirectUrl = settings('websiteURL').url('settings.parasut.oauth');
        if (get('code')) {
          $parasut = new Parasut(settings('parasutClientID'), settings('parasutClientSecret'), settings('parasutCompanyID'));

          $accessTokenResponse = $parasut->getAccessToken(get('code'), $redirectUrl);
          $accessToken = $accessTokenResponse->access_token;
          $refreshToken = $accessTokenResponse->refresh_token;
          $expiresIn = $accessTokenResponse->expires_in;
	        
	        //$createProduct = $parasut->createProduct($accessToken, "Dijital Ürün");
	        //$productID = $createProduct->data->id;

          updateSettings([
            "parasutAccessToken" => $accessToken,
            "parasutRefreshToken" => $refreshToken,
            "parasutTokenExpiryDate" => date('Y-m-d H:i:s', time() + $expiresIn),
	          //'parasutProductID' => $productID,
          ]);

          $redirect = new Redirect(url('dashboard.settings.parasut.index'));
          return $redirect->flash("success", t__('Changes has been saved successfully!'));
        } else {
          redirect('https://api.parasut.com/oauth/authorize?client_id='.settings('parasutClientID').'&redirect_uri='.$redirectUrl.'&response_type=code');
        }
      }
    }
}