<?php

namespace Dashboard\Controllers\Store;

use Curl\Curl;
use Dashboard\Core\Controller;
use Dashboard\Services\DiscordWebhookService;
use Translator\Exception;
use Woeler\DiscordPhp\Exception\DiscordInvalidResponseException;
use Woeler\DiscordPhp\Message\DiscordEmbedMessage;
use Woeler\DiscordPhp\Webhook\DiscordWebhook;

class CreditSendController extends Controller
{
    public function __construct()
    {
        abort_perm(['MANAGE_STORE', 'MANAGE_ACCOUNTS']);
    }

    public function index()
    {
        $account = null;
        if (get("id")) {
          $account = db()->prepare("SELECT * FROM Accounts WHERE id = :user OR username = :user");
          $account->execute(array(
            'user' => get("id")
          ));
          $account = $account->fetch();
        }

        return view('store.credit.send.index', compact('account'));
    }

  /**
   * @throws DiscordInvalidResponseException
   */
  public function send()
    {
        validate([
            'userID' => 'required',
            'amount' => 'required',
            'isEarnings' => 'required|boolean'
        ]);

        $account = db()->prepare("SELECT * FROM Accounts WHERE id = ?");
        $account->execute(array(input("userID")));
        $account = $account->fetch();

        if (!$account) {
            return back()->flash("error", t__('User not found!'));
        }

        $insertCreditHistory = db()->prepare("INSERT INTO CreditHistory (accountID, type, price, creationDate) VALUES (?, ?, ?, ?)");
        $insertCreditHistory->execute(array($account["id"], 1, input("amount"), datetime()));

        $createOrder = db()->prepare("INSERT INTO Orders (accountID, coupon, total, discount, subtotal, tax, paymentID, paymentAPI, status, type, credit, earnings, creationDate) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
        $createOrder->execute(array(
          $account["id"],
          null,
          input("amount"),
          0,
          input("amount"),
					0,
          "",
          "manual",
          1,
          2,
          0,
          input('isEarnings') ? input("amount") : 0,
          date("Y-m-d H:i:s")
        ));

        $updateAccounts = db()->prepare("UPDATE Accounts SET credit = credit + ? WHERE id = ?");
        $updateAccounts->execute(array(input("amount"), $account["id"]));
				
				DiscordWebhookService::send('store.purchase.credit', [
					"username" => $account["realname"],
					"credit" => input("amount"),
					"currency" => settings('currency'),
				]);

        createLog('CREDITS_SENT', [
          'username' => $account["realname"],
          'amount' => input("amount")
        ]);

        return back()->flash('success', t__('The credit has been sent successfully!'));
    }
}