<?php
$breadcrumbs = [
    [
        'url' => 'dashboard.servers.index',
        'text' => t__('Servers')
    ],
    [
        'text' => t__('Edit')
    ]
];
$this->layout('layouts/main', [
    'title' => t__('Editing %text%', ['%text%' => $server['name']]),
    'category' => 'store.servers',
    'breadcrumbs' => $breadcrumbs
]) ?>

<section class="py-9 los-container tight-container">
    <div class="los-page-heading">
        <h1 class="text-gray-950">
            <?php e__('Editing %text%', ['%text%' => $server['name']]) ?>
        </h1>
	      <div class="flex gap-2">
		      <a href="<?php echo leaderosHelpUrl() ?>/using-leaderos/store/game-servers" class="btn btn-dark" target="_blank">
			      <?php e__('Help') ?>
		      </a>
		      <a href="<?php echo url('dashboard.servers.index') ?>" class="btn btn-default">
		          <?php e__('Back') ?>
		      </a>
	      </div>
    </div>

    <?php _message(); ?>

    <div class="card p-6 mt-10">
        <form action="<?php echo url('dashboard.servers.update', ['id' => $server['id']]) ?>" method="post" class="grid gap-4" data-submit-loading>
            <?php _method('PATCH') ?>
            <div>
                <label for="name" class="form-label">
                    <?php e__('Name') ?>
                </label>
                <input value="<?php _old('name', $server['name']) ?>" type="text" id="name" name="name" class="form-control">
            </div>
            <div>
                <label for="ip" class="form-label">
                    <?php e__('Server IP') ?>
                </label>
                <input value="<?php _old('ip', $server['ip']) ?>" type="text" id="ip" name="ip" class="form-control">
            </div>
            <div>
                <label for="port" class="form-label">
                    <?php e__('Server Port') ?>
                </label>
                <input value="<?php _old('port', $server['port']) ?>" type="number" id="port" name="port" class="form-control">
            </div>
            <div class="grid gap-4" x-data="{consoleID: '<?php _old('consoleID', $server["consoleID"]); ?>'}">
              <div>
                <label for="consoleID" class="form-label">
                  <?php e__('Console Type') ?>
                </label>
                <select x-data="select2Alpine()" name="consoleID" id="consoleID" x-init="changed('consoleID',() => consoleID=selected)" required>
                  <?php if (settings('gameType') == 'minecraft'): ?>
	                  <option value="4" <?php _selected(old('consoleID', $server["consoleID"]) == '4'); ?>>
		                  LeaderOS Connect
	                  </option>
	                  <option value="1" <?php _selected(old('consoleID', $server["consoleID"]) == '1'); ?>>
		                  Websend
	                  </option>
	                  <option value="2" <?php _selected(old('consoleID', $server["consoleID"]) == '2'); ?>>
		                  Rcon
	                  </option>
	                  <option value="3" <?php _selected(old('consoleID', $server["consoleID"]) == '3'); ?>>
		                  Websender
	                  </option>
                  <?php else: ?>
	                  <option value="2" <?php _selected(old('consoleID', $server["consoleID"]) == '2'); ?>>
		                  Rcon
	                  </option>
                  <?php endif; ?>
                </select>
              </div>
              <div x-show="consoleID !== '4'">
                <label for="consolePort" class="form-label">
                  <?php e__('Console Port') ?>
                </label>
                <input value="<?php _old('consolePort', $server['consolePort']) ?>" type="number" id="consolePort" name="consolePort" class="form-control">
              </div>
              <div x-show="consoleID !== '4'">
                <label for="consolePassword" class="form-label">
                  <?php e__('Console Password') ?>
                </label>
                <input value="<?php _old('consolePassword', $server['consolePassword']) ?>" type="password" id="consolePassword" name="consolePassword" class="form-control">
              </div>
              <div x-show="consoleID === '4' && <?php echo $server["consoleID"] == 4 ? "true" : "false"; ?>">
                <label for="consoleToken" class="form-label">
                  <?php e__('Console Token') ?>
                </label>
                <div x-data="serverToken('<?php echo $server['consoleToken']; ?>', '<?php echo url('dashboard.servers.resetConsoleToken', ['id' => $server["id"]]) ?>')" class="input-absolute-group-right select-none">
                  <input x-bind:value="token" x-bind:type="showToken ? 'text' : 'password'" id="consoleToken" name="consoleToken" class="form-control" readonly>
                  <div class="flex gap-2 items-center">
                    <div>
                      <button type="button" x-show="!showToken" @click="showToken = true" class="flex items-center justify-center gap-2 bg-gray-50 dark:bg-gray-200/10 text-gray-600 dark:text-white text-sm px-2.5 py-0.5 rounded-md h-[28px]">
                        <i class="stroke-gray-600 dark:stroke-white w-4" data-feather="eye"></i>
                        <?php e__('Show') ?>
                      </button>
                      <button type="button" x-show="showToken" @click="showToken = false" class="flex items-center justify-center gap-2 bg-gray-50 dark:bg-gray-200/10 text-gray-600 dark:text-white text-sm px-2.5 py-0.5 rounded-md h-[28px]">
                        <i class="stroke-gray-600 dark:stroke-white w-4" data-feather="eye-slash"></i>
                        <?php e__('Hide') ?>
                      </button>
                    </div>
                    <div>
                      <button type="button" @click="resetServerToken()" class="flex items-center justify-center gap-2 bg-red-500 text-white text-sm px-2.5 py-0.5 rounded-md h-[28px]" :class="isLoading && 'opacity-75 pointer-events-none'">
                        <i x-show="!isLoading" class="text-white w-4" data-feather="refresh-2"></i>
                        <svg x-show="isLoading" class="animate-spin h-4 w-4 text-white" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                          <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
                          <path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                        </svg>
                        <?php e__('Reset') ?>
                      </button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
            <div class="">
                <button type="button" @click="checkConsole()" class="btn btn-default flex items-center ring-0">
                  <svg style="display: none;" class="animate-spin -ml-1 mr-3 h-5 w-5 text-gray-500" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24">
                    <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
                    <path class="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
                  </svg>
                  <span>
                    <?php e__('Check Console Connection') ?>
                  </span>
                </button>
            </div>

            <div class="flex justify-end">
                <?php _csrf(); ?>
                <button type="submit" class="btn btn-success">
                    <?php e__('Save Changes') ?>
                </button>
            </div>
        </form>
    </div>
</section>

