<?php
$breadcrumbs = [
    [
        'url' => 'dashboard.settings.index',
        'text' => t__('Settings')
    ],
    [
        'text' => t__('Discord Bot')
    ]
];
$this->layout('layouts/main', [
    'title' => t__('Discord Bot Settings'),
    'category' => 'settings.discord-bot-legacy',
    'breadcrumbs' => $breadcrumbs
]) ?>

<section class="los-container tight-container py-9">
    <div class="los-page-heading">
        <h1 class="text-gray-950"><?php e__('Discord Bot Settings') ?></h1>
        <div class="flex gap-2">
	        <a href="<?php echo leaderosHelpUrl() ?>/integrations/discord-bot-legacy" class="btn btn-dark" target="_blank">
		        <?php e__('Help') ?>
	        </a>
	        <a href="<?php echo url('dashboard.settings.index') ?>" class="btn btn-default">
		        <?php e__('Back') ?>
	        </a>
        </div>
    </div>

    <?php _message(); ?>

    <div class="alert alert-info mt-10">
      <p class="dark:text-gray-300 font-medium">
        <?php e__('Redirect URLs') ?>:
      </p>
      <pre class="flex flex-col mt-2">
        <span><?php echo settings('websiteURL') . "/discord/login"; ?></span>
        <span><?php echo settings('websiteURL') . "/discord/link"; ?></span>
        <span><?php echo settings('websiteURL') . "/discord/unlink"; ?></span>
      </pre>
    </div>

    <form action="<?php echo url('dashboard.settings.discord-bot-legacy.update') ?>" method="post" enctype="multipart/form-data" class="grid gap-4">
        <?php _method('PATCH'); ?>
        <div class="mt-10 card p-6 grid gap-4">
            <div>
                <label for="discordClientID" class="form-label"><?php e__('Client ID') ?>:</label>
                <div>
                    <input type="text" id="discordClientID" class="form-control" name="discordClientID"
                           value="<?php _old('discordClientID', settings('discordClientID')); ?>">
                </div>
            </div>
            <div>
                <label for="discordClientSecret" class="form-label"><?php e__('Client Secret') ?>:</label>
                <div>
                    <input type="text" id="discordClientSecret" class="form-control" name="discordClientSecret"
                           value="<?php _old('discordClientSecret', settings('discordClientSecret')); ?>">
                </div>
            </div>
            <div>
                <label for="discordBotToken" class="form-label"><?php e__('Bot Token') ?>:</label>
                <div>
                    <input type="text" id="discordBotToken" class="form-control" name="discordBotToken"
                           value="<?php _old('discordBotToken', settings('discordBotToken')); ?>">
                </div>
            </div>
            <div>
                <label for="discordGuildID" class="form-label"><?php e__('Server ID') ?>:</label>
                <div>
                    <input type="text" id="discordGuildID" class="form-control" name="discordGuildID"
                           value="<?php _old('discordGuildID', settings('discordGuildID')); ?>">
                </div>
            </div>
            <div>
              <label for="discordJoinServerStatus" class="form-label"><?php e__('Join Discord Server') ?>:</label>
              <div>
                <select x-data="select2Alpine()" name="discordJoinServerStatus" id="discordJoinServerStatus">
                  <option value="0" <?php _selected(old('discordJoinServerStatus', settings('discordJoinServerStatus')) == '0'); ?>>
                    <?php e__('Disable') ?>
                  </option>
                  <option value="1" <?php _selected(old('discordJoinServerStatus', settings('discordJoinServerStatus')) == '1'); ?>>
                    <?php e__('Enable') ?>
                  </option>
                </select>
              </div>
            </div>
            <div>
                <label for="discordEveryoneRoleID" class="form-label"><?php e__('Everyone Role ID') ?>:</label>
                <div>
                    <input type="text" id="discordEveryoneRoleID" class="form-control" name="discordEveryoneRoleID"
                           value="<?php _old('discordEveryoneRoleID', settings('discordEveryoneRoleID')); ?>">
                </div>
            </div>
            <div>
                <label for="discordSyncedRoleID" class="form-label"><?php e__('Synced Role ID') ?>:</label>
                <div>
                    <input type="text" id="discordSyncedRoleID" class="form-control" name="discordSyncedRoleID"
                           value="<?php _old('discordSyncedRoleID', settings('discordSyncedRoleID')); ?>">
                </div>
            </div>
            <div x-data="{discordRoleSyncingStatus: '<?php _old('discordRoleSyncingStatus', settings('discordRoleSyncingStatus')); ?>'}">
                <div>
                    <label for="discordRoleSyncingStatus" class="form-label"><?php e__('Role Syncing') ?>:</label>
                    <div>
                        <select x-data="select2Alpine()" x-init="changed('discordRoleSyncingStatus', () => discordRoleSyncingStatus = selected)" name="discordRoleSyncingStatus" id="discordRoleSyncingStatus">
                            <option value="0" <?php _selected(old('discordRoleSyncingStatus', settings('discordRoleSyncingStatus')) == '0'); ?>>
                                <?php e__('Disable') ?>
                            </option>
                            <option value="1" <?php _selected(old('discordRoleSyncingStatus', settings('discordRoleSyncingStatus')) == '1'); ?>>
                                <?php e__('Enable') ?>
                            </option>
                        </select>
                    </div>
                </div>
            </div>
            <div x-data="{discordSetNicknameStatus: '<?php _old('discordSetNicknameStatus', settings('discordSetNicknameStatus')); ?>'}">
              <div>
                <label for="discordSetNicknameStatus" class="form-label"><?php e__('Set Nickname') ?>:</label>
                <div>
                  <select x-data="select2Alpine()" x-init="changed('discordSetNicknameStatus', () => discordSetNicknameStatus = selected)" name="discordSetNicknameStatus" id="discordSetNicknameStatus">
                    <option value="0" <?php _selected(old('discordSetNicknameStatus', settings('discordSetNicknameStatus')) == '0'); ?>>
                      <?php e__('Disable') ?>
                    </option>
                    <option value="1" <?php _selected(old('discordSetNicknameStatus', settings('discordSetNicknameStatus')) == '1'); ?>>
                      <?php e__('Enable') ?>
                    </option>
                  </select>
                </div>
              </div>
            </div>
        </div>
        <div class="card p-6">
            <div x-data="{discordTicketStatus: '<?php _old('discordTicketStatus', settings('discordTicketStatus')); ?>'}">
                <div>
                    <label for="discordTicketStatus" class="form-label"><?php e__('Support Tickets') ?>:</label>
                    <div>
                        <select x-data="select2Alpine()" x-init="changed('discordTicketStatus', () => discordTicketStatus = selected)" name="discordTicketStatus" id="discordTicketStatus">
                            <option value="0" <?php _selected(old('discordTicketStatus', settings('discordTicketStatus')) == '0'); ?>>
                                <?php e__('Disable') ?>
                            </option>
                            <option value="1" <?php _selected(old('discordTicketStatus', settings('discordTicketStatus')) == '1'); ?>>
                                <?php e__('Enable') ?>
                            </option>
                        </select>
                    </div>
                </div>
                <div x-show="discordTicketStatus === '1'">
                    <div class="mt-3">
                        <label for="discordTicketCategoryID" class="form-label"><?php e__('Ticket Discord Category ID') ?>:</label>
                        <div>
                            <input type="text" id="discordTicketCategoryID" class="form-control" name="discordTicketCategoryID"
                                   value="<?php _old('discordTicketCategoryID', settings('discordTicketCategoryID')); ?>">
                        </div>
                    </div>
                    <div class="mt-3">
                        <label for="discordTicketStaffRoleID" class="form-label"><?php e__('Ticket Staff Role ID') ?>:</label>
                        <div>
                            <input type="text" id="discordTicketStaffRoleID" class="form-control" name="discordTicketStaffRoleID"
                                   value="<?php _old('discordTicketStaffRoleID', settings('discordTicketStaffRoleID')); ?>">
                        </div>
                    </div>
                    <div class="mt-3">
                      <label for="discordTicketEmbedDetailsTemplate" class="form-label"><?php e__('Ticket Embed Message Template') ?>:</label>
                      <div>
                        <textarea name="discordTicketEmbedDetailsTemplate" id="discordTicketEmbedDetailsTemplate" rows="5" class="form-control"><?php _old('discordTicketEmbedDetailsTemplate', settings('discordTicketEmbedDetailsTemplate')); ?></textarea>
                      </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="flex justify-end">
            <?php _csrf(); ?>
            <button type="submit" class="btn btn-success"><?php e__('Save Changes') ?></button>
        </div>
    </form>
</section>