<?php
$breadcrumbs = [
	[
		'url' => 'dashboard.settings.index',
		'text' => t__('Settings')
	],
	[
		'text' => t__('Discord Bot')
	]
];
$this->layout('layouts/main', [
	'title' => t__('Discord Bot'),
	'category' => 'settings.discord-bot',
	'breadcrumbs' => $breadcrumbs
]) ?>

<?php if (!$isLinked): ?>
	<section class="los-container py-9">
		<?php _message(); ?>
		<div class="center flex-col mt-20 mb-32">
			
			<i class="w-16 h-16 stroke-gray-600" data-feather="discord"></i>
			
			<h3 class="mt-8 text-gray-800">
				<?php e__('Discord Bot is not connected') ?>
			</h3>
			<p class="text-gray-500 mt-2 max-w-lg mx-auto text-center">
				<?php e__('You need to connect your Discord server to use this feature.') ?>
			</p>
			<div class="mt-8 flex gap-2">
				<a href="<?php echo url('dashboard.settings.discord-bot.link'); ?>" class="btn btn-success"><?php e__('Connect Discord Server') ?></a>
			</div>
		</div>
	</section>
<?php else: ?>
	<section class="py-9 los-container tight-container">
		<div class="los-page-heading">
			<h1 class="text-gray-950">
				<?php e__('Discord Bot Settings') ?>
			</h1>
		</div>
		
		<?php _message(); ?>
		
		<div class="card p-6 mt-10">
			<form action="<?php url('dashboard.settings.discord-bot.update') ?>" method="post" class="grid gap-4">
				<?php _method('PATCH') ?>
				
				<div>
					<label for="guildID" class="form-label"><?php e__('Server ID') ?>:</label>
					<div class="input-absolute-group-right">
						<input type="text" id="guildID" class="form-control" value="<?php echo settings('discordBotSettingsGuildID'); ?>" readonly>
						<div x-data="unlinkDiscordBot('<?php echo url('dashboard.settings.discord-bot.reset') ?>')">
							<button
								type="button"
								class="btn btn-danger flex items-center gap-2 !text-sm !px-2.5 !py-0.5 rounded-md"
								@click="unlinkDiscordBotRequest()"
								x-bind:disabled="isLoading"
								:class="isLoading ? 'opacity-50 pointer-events-none' : ''"
							>
								<i class="stroke-gray-600 dark:stroke-white w-4" data-feather="link-21"></i>
								<?php e__('Unlink Bot') ?>
							</button>
						</div>
					</div>
				</div>
				
				<?php $this->insert('components/toggle', [
					'name' => 'discordBotSettingsSyncNames',
					'default' => old('discordBotSettingsSyncNames', settings('discordBotSettingsSyncNames')),
					'labelRight' => t__('Sync Username'),
				]); ?>
				
				
				<div class="flex justify-end">
					<?php _csrf(); ?>
					<button type="submit" class="btn btn-success">
						<?php e__('Save Changes') ?>
					</button>
				</div>
			</form>
		</div>
	</section>
<?php endif; ?>
