<?php
$breadcrumbs = [
    [
        'url' => 'dashboard.settings.index',
        'text' => t__('Settings')
    ],
    [
        'text' => t__('System')
    ]
];
$this->layout('layouts/main', [
    'title' => t__('System Settings'),
    'category' => 'settings.system',
    'breadcrumbs' => $breadcrumbs
]) ?>

<section class="los-container tight-container py-9">
    <div class="los-page-heading">
        <h1 class="text-gray-950"><?php e__('System Settings') ?></h1>
		    <div class="flex gap-2">
			    <a href="<?php echo leaderosHelpUrl() ?>/settings/system" class="btn btn-dark" target="_blank">
				    <?php e__('Help') ?>
			    </a>
	        <a href="<?php echo url('dashboard.settings.index') ?>" class="btn btn-default">
	            <?php e__('Back') ?>
	        </a>
		    </div>
    </div>

    <?php _message(); ?>

    <div
      class="mt-10 card p-6"
      x-data="{
        storeRedirectionStatus: '<?php _old('storeRedirectStatus', settings('storeRedirect') == '' ? '0' : '1') ?>',
        cashbackStatus: '<?php _old('cashbackStatus', settings('cashback') == 0 ? '0' : '1') ?>',
        oneSignalStatus: '<?php _old('oneSignalStatus', (settings("oneSignalAppID") == '0' || settings("oneSignalAPIKey") == '0') ? '0' : '1') ?>',
        tawktoStatus: '<?php _old('tawktoStatus', settings('tawktoID') == '0' ? '0' : '1') ?>',
        bonusCreditStatus: '<?php _old('bonusCreditStatus', settings('bonusCredit') == '0' ? '0' : '1') ?>',
        googleAnalyticsStatus: '<?php _old('analyticsStatus', settings('analyticsUA') == '0' ? '0' : '1') ?>',
        recaptchaStatus: '<?php _old('recaptchaStatus', (settings("recaptchaPublicKey") == '0' || settings("recaptchaPrivateKey") == '0') ? '0' : '1') ?>',
      }"
    >
        <form action="<?php echo url('dashboard.settings.system.update') ?>" method="post" class="flex flex-col gap-4">
            <?php _method('PATCH'); ?>
            <div>
                <label for="selectTimezone" class="form-label"><?php e__('Timezone') ?>:</label>
                <div>
                    <select x-data="select2Alpine(true)" id="selectTimezone" class="form-control" name="timezone" data-toggle="select">
                        <?php
                        $zoneIdentifiers = timezone_identifiers_list();
                        $zoneLocations = array();

                        foreach ($zoneIdentifiers as $zoneIdentifier) {
                            $zone = explode('/', $zoneIdentifier);
                            $desiredRegions = array(
                                'Africa',
                                'America',
                                'Antarctica',
                                'Arctic',
                                'Asia',
                                'Atlantic',
                                'Australia',
                                'Europe',
                                'Indian',
                                'Pacific'
                            );
                            if (in_array($zone[0], $desiredRegions)) {
                                if (isset($zone[1]) != '') {
                                    $area = str_replace('_', ' ', $zone[1]);
                                    if (!empty($zone[2])) {
                                        $area = $area . ' (' . str_replace('_', ' ', $zone[2]) . ')';
                                    }
                                    $zoneLocations[$zone[0]][$zoneIdentifier] = $zone[0] . '/' . $area;
                                }
                            }
                        }

                        foreach ($zoneLocations as $zoneRegion => $regionAreas) {
                            foreach ($regionAreas as $regionArea => $zoneLabel) {
                                $currentTimeInZone = new DateTime("now", new DateTimeZone($regionArea));
                                $currentTimeDiff = $currentTimeInZone->format('P');
                                echo '<option value="' . $regionArea . '" ' . ($regionArea == settings("timezone") ? "selected" : null) . '>(GMT ' . $currentTimeDiff . ') ' . $zoneLabel . '</option>';
                            }
                        }
                        ?>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectUpdateNotifications" class="form-label"><?php e__('Update Notifications') ?>:</label>
                <div>
                    <select x-data="select2Alpine()" id="selectUpdateNotifications" class="form-control" name="updateNotifications">
                        <option value="0" <?php echo (settings("updateNotifications") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("updateNotifications") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectDebugModeStatus" class="form-label">DEBUG Mod:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectDebugModeStatus" class="form-control" name="debugModeStatus">
                        <option value="0" <?php echo (settings("debugModeStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("debugModeStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
		        <div>
			        <label for="allowCustomAvatars" class="form-label"><?php e__('Allow Custom Avatar Upload') ?>:</label>
			        <div>
				        <select x-data="select2Alpine()" id="allowCustomAvatars" class="form-control" name="allowCustomAvatars">
					        <option value="0" <?php echo (settings("allowCustomAvatars") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
					        <option value="1" <?php echo (settings("allowCustomAvatars") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
				        </select>
			        </div>
		        </div>
		        <div>
			        <label for="emailChangeVerification" class="form-label"><?php e__('Email Change Verification') ?>:</label>
			        <div>
				        <select x-data="select2Alpine()" id="emailChangeVerification" class="form-control" name="emailChangeVerification">
					        <option value="0" <?php echo (settings("emailChangeVerification") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
					        <option value="1" <?php echo (settings("emailChangeVerification") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
				        </select>
			        </div>
		        </div>
            <?php if (settings('gameType') == 'minecraft'): ?>
	            <div>
		            <label for="selectAvatarAPI" class="form-label">Avatar API:*</label>
		            <div>
			            <select x-data="select2Alpine()" id="selectAvatarAPI" class="form-control" name="avatarAPI">
				            <option value="1" <?php echo (settings("avatarAPI") == 1) ? 'selected="selected"' : null; ?>>minotar.net (<?php e__('Recommended') ?>)</option>
				            <option value="2" <?php echo (settings("avatarAPI") == 2) ? 'selected="selected"' : null; ?>>cravatar.eu</option>
			            </select>
		            </div>
	            </div>
	            <div>
		            <label for="selectOnlineAPI" class="form-label">Online API:*</label>
		            <div>
			            <select x-data="select2Alpine()" id="selectOnlineAPI" class="form-control" name="onlineAPI">
				            <option value="1" <?php echo (settings("onlineAPI") == 1) ? 'selected="selected"' : null; ?>>mcapi.us (<?php e__('Recommended') ?>)</option>
				            <option value="2" <?php echo (settings("onlineAPI") == 2) ? 'selected="selected"' : null; ?>>mc-api.net</option>
				            <option value="3" <?php echo (settings("onlineAPI") == 3) ? 'selected="selected"' : null; ?>>mcapi.tc</option>
				            <option value="4" <?php echo (settings("onlineAPI") == 4) ? 'selected="selected"' : null; ?>>keyubu.net</option>
				            <option value="5" <?php echo (settings("onlineAPI") == 5) ? 'selected="selected"' : null; ?>>mcsrvstat.us</option>
				            <option value="6" <?php echo (settings("onlineAPI") == 6) ? 'selected="selected"' : null; ?>>mcsrvstat.us (Pocket Edition)</option>
			            </select>
		            </div>
	            </div>
            <?php endif; ?>
            <div>
                <label for="selectPasswordType" class="form-label"><?php e__('Password Hashing') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectPasswordType" class="form-control" name="passwordType">
                        <option value="1" <?php echo (settings("passwordType") == 1) ? 'selected="selected"' : null; ?>>SHA256</option>
                        <option value="2" <?php echo (settings("passwordType") == 2) ? 'selected="selected"' : null; ?>>MD5</option>
                        <option value="3" <?php echo (settings("passwordType") == 3) ? 'selected="selected"' : null; ?>>Bcrypt</option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectSSLStatus" class="form-label"><?php e__('HTTPS Redirect') ?> (SSL):*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectSSLStatus" class="form-control" name="sslStatus">
                        <option value="0" <?php echo (settings("sslStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("sslStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectMaintenanceStatus" class="form-label"><?php e__('Maintenance') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectMaintenanceStatus" class="form-control" name="maintenanceStatus">
                        <option value="0" <?php echo (settings("maintenanceStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("maintenanceStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
	        
            <div>
                <label for="selectRegistrationStatus" class="form-label"><?php e__('Registration') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectRegistrationStatus" class="form-control" name="registrationStatus">
                        <option value="0" <?php echo (settings("registrationStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("registrationStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
              <label for="forceDefaultLanguage" class="form-label"><?php e__('Force Default Language') ?>:</label>
              <div>
                <select x-data="select2Alpine()" id="forceDefaultLanguage" class="form-control" name="forceDefaultLanguage">
                  <option value="0" <?php echo (settings("forceDefaultLanguage") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                  <option value="1" <?php echo (settings("forceDefaultLanguage") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                </select>
              </div>
            </div>
		        <div>
			        <label for="tax" class="form-label"><?php e__('Tax') ?> (%):</label>
			        <div>
				        <input type="text" id="tax" class="form-control" name="tax" value="<?php _old('tax', settings('tax')) ?>">
			        </div>
		        </div>
            <div>
                <label for="selectCreditPackageStatus" class="form-label"><?php e__('Credit Packages') ?>:</label>
                <div>
                    <select x-data="select2Alpine()" id="selectCreditPackageStatus" class="form-control" name="creditPackageStatus">
                        <option value="0" <?php echo (settings("creditPackageStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("creditPackageStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
              <label for="isCreditRequiredOnPurchase" class="form-label"><?php e__('Only allow purchases with Credits') ?>:</label>
              <div>
                <select x-data="select2Alpine()" id="isCreditRequiredOnPurchase" class="form-control" name="isCreditRequiredOnPurchase">
                  <option value="0" <?php echo (settings("isCreditRequiredOnPurchase") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                  <option value="1" <?php echo (settings("isCreditRequiredOnPurchase") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                </select>
              </div>
            </div>
            <div>
              <label for="removeMoneyZeroDecimal" class="form-label"><?php e__('Remove .00 from money') ?>:</label>
              <div>
                <select x-data="select2Alpine()" id="removeMoneyZeroDecimal" class="form-control" name="removeMoneyZeroDecimal">
                  <option value="0" <?php echo (settings("removeMoneyZeroDecimal") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                  <option value="1" <?php echo (settings("removeMoneyZeroDecimal") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                </select>
              </div>
            </div>
            <div>
              <label for="creditText" class="form-label"><?php e__('Credit Text') ?>:</label>
              <div>
                <input type="text" id="creditText" class="form-control" name="creditText" value="<?php _old('creditText', settings('creditText')) ?>">
              </div>
            </div>
            <div>
                <label for="selectCreditStatus" class="form-label"><?php e__('Players Can Send Credits to Each Other') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectCreditStatus" class="form-control" name="creditStatus">
                        <option value="0" <?php echo (settings("creditStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("creditStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectGiftStatus" class="form-label"><?php e__('Players Can Send Gifts to Each Other') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectGiftStatus" class="form-control" name="giftStatus">
                        <option value="0" <?php echo (settings("giftStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("giftStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectTopSalesStatus" class="form-label"><?php e__('Bestseller') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectTopSalesStatus" class="form-control" name="topSalesStatus">
                        <option value="0" <?php echo (settings("topSalesStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("topSalesStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectFeaturedProducts" class="form-label"><?php e__('Featured Products') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectFeaturedProducts" class="form-control" name="featuredProducts">
                        <option value="0" <?php echo (settings("featuredProducts") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("featuredProducts") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div>
                <label for="selectStoreRedirectStatus" class="form-label"><?php e__('Store Redirection') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" x-init="changed('storeRedirectStatus', () => storeRedirectionStatus = selected)" id="selectStoreRedirectStatus" class="form-control" name="storeRedirectStatus">
                        <option value="0" <?php echo (settings("storeRedirect") == '') ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("storeRedirect") != '') ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div x-show="storeRedirectionStatus === '1'">
              <label for="inputStoreRedirect" class="form-label"><?php e__('Store Redirect URL') ?>:</label>
              <div>
                <input type="text" id="inputStoreRedirect" class="form-control" name="storeRedirect" value="<?php _old('storeRedirect', settings('storeRedirect')) ?>">
              </div>
            </div>
            <div>
                <label for="selectCashbackStatus" class="form-label"><?php e__('Cashback') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" x-init="changed('cashbackStatus', () => cashbackStatus = selected)" id="selectCashbackStatus" class="form-control" name="cashbackStatus">
                        <option value="0" <?php echo (settings("cashback") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("cashback") != 0) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div x-show="cashbackStatus === '1'">
              <label for="inputCashback" class="form-label"><?php e__('Cashback') ?> (%):</label>
              <div>
                <input type="text" id="inputCashback" class="form-control" name="cashback" value="<?php _old('cashback', settings('cashback') != '0' ? settings('cashback') : '') ?>">
              </div>
            </div>
            <div>
                <label for="inputBazaarCommission" class="form-label"><?php e__('Bazaar Commission') ?> (%):</label>
                <div>
                    <input type="text" id="inputBazaarCommission" class="form-control" name="bazaarCommission" value="<?php _old('bazaarCommission', settings('bazaarCommission')) ?>">
                </div>
            </div>
            <div>
              <label for="showTermsCheckbox" class="form-label"><?php e__('Show Terms Checkbox in Checkout') ?>:*</label>
              <div>
                <select x-data="select2Alpine()" id="showTermsCheckbox" class="form-control" name="showTermsCheckbox">
                  <option value="0" <?php echo (settings("showTermsCheckbox") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                  <option value="1" <?php echo (settings("showTermsCheckbox") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                </select>
              </div>
            </div>
            <div>
                <label for="selectCommentsStatus" class="form-label"><?php e__('Comments') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" id="selectCommentsStatus" class="form-control" name="commentsStatus">
                        <option value="0" <?php echo (settings("commentsStatus") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("commentsStatus") == 1) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <?php if (!moduleIsDisabled('tawkto')): ?>
	            <div>
		            <label for="inputTawktoID" class="form-label">Tawkto Property ID:</label>
		            <div>
			            <input type="text" id="inputTawktoID" class="form-control" name="tawktoID" value="<?php _old('tawktoID', settings('tawktoID') != '0' ? settings('tawktoID') : '') ?>">
		            </div>
	            </div>
	            <div>
		            <label for="inputTawktoWidgetID" class="form-label">Tawkto Widget ID:</label>
		            <div>
			            <input type="text" id="inputTawktoWidgetID" class="form-control" name="tawktoWidgetID" value="<?php _old('tawktoWidgetID', settings('tawktoID') != '0' ? settings('tawktoWidgetID') : '') ?>">
		            </div>
	            </div>
            <?php endif; ?>
            <div>
                <label for="selectBonusCreditStatus" class="form-label"><?php e__('Bonus Credit') ?>:*</label>
                <div>
                    <select x-data="select2Alpine()" x-init="changed('bonusCreditStatus', () => bonusCreditStatus = selected)" id="selectBonusCreditStatus" class="form-control" name="bonusCreditStatus">
                        <option value="0" <?php echo (settings("bonusCredit") == 0) ? 'selected="selected"' : null; ?>><?php e__('Disable') ?></option>
                        <option value="1" <?php echo (settings("bonusCredit") != 0) ? 'selected="selected"' : null; ?>><?php e__('Active') ?></option>
                    </select>
                </div>
            </div>
            <div id="bonusCreditOptions" x-show="bonusCreditStatus === '1'">
                <div>
                    <label for="inputBonusCredit" class="form-label"><?php e__('Bonus Credit Percentage') ?> (%):</label>
                    <div>
                        <input type="number" id="inputBonusCredit" class="form-control" name="bonusCredit" value="<?php _old('bonusCredit', settings('bonusCredit')) ?>">
                    </div>
                </div>
                <div>
                    <label for="inputBonusCreditMinAmount" class="form-label"><?php e__('Min Payment Amount for Bonus Credit') ?>:</label>
                    <div>
                        <input type="number" id="inputBonusCreditMinAmount" class="form-control" name="bonusCreditMinAmount" value="<?php _old('bonusCreditMinAmount', settings('bonusCreditMinAmount')) ?>">
                    </div>
                </div>
              <div x-data="{bonusCreditExpiryStatus: '<?php _old('bonusCreditExpiryStatus', settings('bonusCreditExpiryDate') == '1000-01-01 00:00:00' ? '0' : '1') ?>'}">
                <div>
                  <label for="bonusCreditExpiryStatus" class="form-label">
                    <?php e__('Bonus Credit Duration Status') ?>
                  </label>
                  <select x-data="select2Alpine()" x-init="changed('bonusCreditExpiryStatus', () => bonusCreditExpiryStatus = selected)" name="bonusCreditExpiryStatus" id="bonusCreditExpiryStatus">
                    <option value="0" <?php _selected(old('bonusCreditExpiryStatus', settings('bonusCreditExpiryDate') == '1000-01-01 00:00:00' ? '0' : '1') == '0'); ?>>
                      <?php e__('Lifetime') ?>
                    </option>
                    <option value="1" <?php _selected(old('bonusCreditExpiryStatus', settings('bonusCreditExpiryDate') == '1000-01-01 00:00:00' ? '0' : '1') == '1'); ?>>
                      <?php e__('Temporary') ?>
                    </option>
                  </select>
                </div>
                <div class="mt-3" x-show="bonusCreditExpiryStatus === '1'">
                  <label for="bonusCreditExpiryDate" class="form-label">
                    <?php e__('Bonus Credit Duration') ?>
                  </label>
                  <div class="input-absolute-group">
                    <i data-feather="calendar-2"></i>
                    <input x-data="datePicker()" value="<?php _old('bonusCreditExpiryDate', settings('bonusCreditExpiryDate') != '1000-01-01 00:00:00' ? settings('bonusCreditExpiryDate') : null) ?>" type="text" id="bonusCreditExpiryDate" name="bonusCreditExpiryDate" class="form-control" placeholder="<?php e__('Select date') ?>">
                  </div>
                </div>
              </div>
            </div>
	          <?php if (!moduleIsDisabled('google_analytics')): ?>
		          <div>
			          <div>
				          <label for="inputAnalyticsUA" class="form-label"><?php e__('Google Analytics Identity') ?>:</label>
				          <div>
					          <input type="text" id="inputAnalyticsUA" class="form-control" name="analyticsUA" value="<?php _old('analyticsUA', settings('analyticsUA') != '0' ? settings('analyticsUA') : '') ?>">
				          </div>
			          </div>
		          </div>
	          <?php endif; ?>
            <?php if (!moduleIsDisabled('recaptcha')): ?>
	            <div>
		            <div>
			            <label for="inputRECAPTCHAPagesStatus" class="form-label">Cloudflare Turnstile <?php e__('Active Pages') ?>:</label>
			            <div class="flex flex-col gap-2 mb-3">
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["login"],
						            'labelRight' => t__('Login')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["register"],
						            'labelRight' => t__('Register')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["forgot_password"],
						            'labelRight' => t__('Recover Password')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["reply_blog_post"],
						            'labelRight' => t__('Reply Blog Post')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["open_ticket"],
						            'labelRight' => t__('Open Ticket')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["reply_ticket"],
						            'labelRight' => t__('Reply Ticket')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["tfa"],
						            'labelRight' => t__('2FA')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["post_thread"],
						            'labelRight' => t__('Post Thread')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["reply_thread"],
						            'labelRight' => t__('Reply Thread')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["post_suggestion"],
						            'labelRight' => t__('Post Suggestion')
					            ]); ?>
				            </div>
				            <div class="flex gap-2">
					            <?php $this->insert('components/toggle', [
						            'name' => 'recaptchaPagesStatus[]',
						            'default' => $recaptchaPagesStatus["reply_suggestion"],
						            'labelRight' => t__('Reply Suggestion')
					            ]); ?>
				            </div>
			            </div>
		            </div>
		            <div class="mb-3">
			            <label for="inputRECAPTCHAPublicKey" class="form-label">Cloudflare Turnstile Site Key:</label>
			            <div>
				            <input type="text" id="inputRECAPTCHAPublicKey" class="form-control" name="recaptchaPublicKey" value="<?php _old('recaptchaPublicKey', settings('recaptchaPublicKey') != '0' ? settings('recaptchaPublicKey') : '') ?>">
			            </div>
		            </div>
		            <div>
			            <label for="inputRECAPTCHAPrivateKey" class="form-label">Cloudflare Turnstile Secret Key:</label>
			            <div>
				            <input type="text" id="inputRECAPTCHAPrivateKey" class="form-control" name="recaptchaPrivateKey" value="<?php _old('recaptchaPrivateKey', settings('recaptchaPrivateKey') != '0' ? settings('recaptchaPrivateKey') : '') ?>">
			            </div>
		            </div>
	            </div>
            <?php endif; ?>
            <div>
                <label for="inputMinPay" class="form-label"><?php e__('Min. Payment Amount') ?>:</label>
                <div>
                    <input type="number" id="inputMinPay" class="form-control" name="minPay" min="1" max="99999" value="<?php _old('minPay', settings('minPay')) ?>">
                </div>
            </div>
            <div>
                <label for="inputMaxPay" class="form-label"><?php e__('Max Payment Amount') ?>:</label>
                <div>
                    <input type="number" id="inputMaxPay" class="form-control" name="maxPay" min="1" max="99999" value="<?php _old('maxPay', settings('maxPay')) ?>">
                </div>
            </div>
		        <div>
			        <label for="inputRegisterLimit" class="form-label"><?php e__('Register Limit') ?>:</label>
			        <div>
				        <input type="number" id="inputRegisterLimit" class="form-control" name="registerLimit" value="<?php _old('registerLimit', settings('registerLimit')) ?>">
			        </div>
			        <div class="form-text">
				        <?php e__('Set -1 for unlimited.') ?>
			        </div>
		        </div>
		        <div>
			        <label for="ticketLimit" class="form-label"><?php e__('Maximum Active Support Tickets Allowed') ?>:</label>
			        <div>
				        <input type="number" id="ticketLimit" class="form-control" name="ticketsLimit" value="<?php _old('ticketsLimit', settings('ticketsLimit')) ?>">
			        </div>
			        <div class="form-text">
				        <?php e__('Set -1 for unlimited.') ?>
			        </div>
		        </div>
		        <?php if (settings('loginProvider') == 'default'): ?>
			        <div>
				        <label for="usernameRegex" class="form-label"><?php e__('Username Validation Pattern') ?>:</label>
				        <div>
					        <input type="text" id="usernameRegex" class="form-control" name="usernameRegex" value="<?php _old('usernameRegex', settings('usernameRegex')) ?>">
				        </div>
				        <div class="form-text">
					        <?php e__('Enter a regular expression to define the allowed format for usernames.') ?>
				        </div>
			        </div>
		        <?php endif; ?>
            <?php _csrf(); ?>
            <div class="flex justify-end mt-4">
                <button type="submit" class="btn btn-success"><?php e__('Save Changes') ?></button>
            </div>
        </form>
    </div>
</section>
