<?php

namespace Main\Controllers\Support;

use Main\Libs\Discord;
use Exception;
use League\CommonMark\GithubFlavoredMarkdownConverter;
use Main\Core\Controller;
use Main\Services\AvatarService;
use Main\Services\CkEditorImageUploadService;
use Main\Services\DiscordWebhookService;
use Main\Services\SeoService;

class TicketController extends Controller
{
		protected string $route_type = 'support';
		
    public function index()
    {
	      SeoService::set('support.tickets.index');
				
        $tickets = db()->prepare("SELECT S.*, SC.name as categoryName FROM Supports S INNER JOIN SupportCategories SC ON S.categoryID = SC.id WHERE S.accountID = ? ORDER BY S.updateDate DESC");
		    $tickets->execute(array(auth()->user()->id()));
		    $tickets = $tickets->fetchAll();

        return $this->view('tickets.index', compact('tickets'));
    }

    public function create()
    {
	      SeoService::set('support.tickets.create');
				
				if (settings('ticketsLimit') != "-1") {
					$ticketsCount = db()->prepare("SELECT COUNT(S.id) as ticketsCount FROM Supports S INNER JOIN SupportCategories SC ON S.categoryID = SC.id WHERE S.accountID = ? AND S.statusID != 4");
					$ticketsCount->execute(array(auth()->user()->id()));
					$ticketsCount = $ticketsCount->fetch();
					
					if ($ticketsCount['ticketsCount'] >= (int)settings('ticketsLimit')) {
						return back()->flash('error', t__("You can't open more tickets. Please wait for the staff to respond to your existing tickets."));
					}
				}
			
	      $categories = db()->query("SELECT * FROM SupportCategories");
        $categories = array_map(function ($category) {
	        $fields = db()->prepare("SELECT * FROM CustomSupportFields WHERE categoryId = ? AND isEnabled = ? ORDER BY id ASC");
	        $fields->execute(array($category["id"], 1));
					$category["fields"] = $fields->fetchAll();
					
					return $category;
				}, $categories->fetchAll());

        return $this->view('tickets.create', compact('categories'));
    }

    public function store()
    {
        validate([
            "title" => "required",
            "categoryID" => "required",
            "message" => "required"
        ]);
	    
		    if (recaptcha()->isEnabled('open_ticket') && !recaptcha()->verify()) {
			    return back()->flash('error', t__('Spam detected!'));
		    }
	    
		    $supportCategory = db()->prepare("SELECT * FROM SupportCategories WHERE id = ?");
		    $supportCategory->execute(array(input("categoryID")));
		    $supportCategory = $supportCategory->fetch();
				if (!$supportCategory) abort_404();
	    
		    if (settings('ticketsLimit') != "-1") {
			    $ticketsCount = db()->prepare("SELECT COUNT(S.id) as ticketsCount FROM Supports S INNER JOIN SupportCategories SC ON S.categoryID = SC.id WHERE S.accountID = ? AND S.statusID != 4");
			    $ticketsCount->execute(array(auth()->user()->id()));
			    $ticketsCount = $ticketsCount->fetch();
			    
			    if ($ticketsCount['ticketsCount'] >= (int)settings('ticketsLimit')) {
				    return back()->flash('error', t__("You can't open more tickets. Please wait for the staff to respond to your existing tickets."));
			    }
		    }

        $supportBannedStatus = db()->prepare("SELECT * FROM BannedAccounts WHERE accountID = ? AND categoryID = ? AND (expiryDate > ? OR expiryDate = ?)");
        $supportBannedStatus->execute(array(auth()->user()->id(), 2, datetime(), '1000-01-01 00:00:00'));
        $supportBannedStatus = $supportBannedStatus->fetch();

        if ($supportBannedStatus) {
            return back()->flash('error', t__('You are banned from support!'));
        }
				
				$title = sanitize(input("title"));

        $insertSupports = db()->prepare("INSERT INTO Supports (title, accountID, categoryID, statusID, readStatus, updateDate, creationDate) VALUES (?, ?, ?, ?, ?, ?, ?)");
        $insertSupports->execute(array($title, auth()->user()->id(), $supportCategory["id"], 1, 1, datetime(), datetime()));
        $supportID = db()->lastInsertId();

        $insertSupportMessages = db()->prepare("INSERT INTO SupportMessages (supportID, accountID, message, writeLocation, creationDate) VALUES (?, ?, ?, ?, ?)");
        $insertSupportMessages->execute(array($supportID, auth()->user()->id(), input("message"), 1, datetime()));

        $fieldsForChecking = db()->prepare("SELECT * FROM CustomSupportFields WHERE categoryID = ? AND isEnabled = ? ORDER BY id ASC");
        $fieldsForChecking->execute(array($supportCategory["id"], 1));
        $fieldsForChecking = $fieldsForChecking->fetchAll();
        foreach ($fieldsForChecking as $fieldsForChecking) {
            if ($fieldsForChecking["type"] == 4) {
                foreach ($_POST["field-" . $fieldsForChecking["id"]] as $key => $value) {
                    $field = sanitize($_POST["field-" . $fieldsForChecking["id"]][$key]);
                    $insertFieldValue = db()->prepare("INSERT INTO CustomSupportFieldValues (supportID, fieldID, value) VALUES (?, ?, ?)");
                    $insertFieldValue->execute(array($supportID, $fieldsForChecking["id"], $field));
                }
            } else {
                $field = sanitize(input("field-" . $fieldsForChecking["id"]));
                $insertFieldValue = db()->prepare("INSERT INTO CustomSupportFieldValues (supportID, fieldID, value) VALUES (?, ?, ?)");
                $insertFieldValue->execute(array($supportID, $fieldsForChecking["id"], $field));
            }
        }

        $notificationsVariables = $supportID;
        $insertNotifications = db()->prepare("INSERT INTO Notifications (accountID, type, variables, creationDate) VALUES (?, ?, ?, ?)");
        $insertNotifications->execute(array(auth()->user()->id(), 1, $notificationsVariables, datetime()));
	    
		    DiscordWebhookService::send('support.ticket.opened', [
			    "username" => auth()->user()->displayName(),
			    "title" => $title,
			    "category" => $supportCategory["name"],
			    "message" => input("message"),
			    "dashboard_url" => website_url('/dashboard/support/tickets/' . $supportID),
		    ]);

        if (modules('discord')->isActive() && settings("discordTicketStatus") == '1') {
            $supportCustomFields = db()->prepare("SELECT CSFV.value, CSV.field FROM CustomSupportFieldValues CSFV INNER JOIN CustomSupportFields CSV ON CSV.id = CSFV.fieldID WHERE CSFV.supportID = ?");
            $supportCustomFields->execute(array($supportID));
            $supportCustomFields = $supportCustomFields->fetchAll();

            $discord = new Discord(settings("discordClientID"), settings("discordClientSecret"), settings("discordBotToken"));
            $discordTicketRequest = $discord->createTicket(
                settings("discordGuildID"),
                settings("discordTicketCategoryID"),
                $supportID,
                $supportCustomFields,
                $supportCategory["name"],
	              $title,
                input("message"),
                auth()->user()->displayName(),
                auth()->user()->data("discordUserID"),
                settings("discordEveryoneRoleID"),
                settings("discordTicketStaffRoleID"),
                settings("discordTicketEmbedDetailsTemplate"),
            );
            if ($discordTicketRequest->id != null) {
                $updateSupports = db()->prepare("UPDATE Supports SET discordChannelID = ? WHERE id = ?");
                $updateSupports->execute(array($discordTicketRequest->id, $supportID));
            }
        }

        redirect(url('support.tickets.show', ['id' => $supportID]));
    }

    public function show($id)
    {
		    $ticket = db()->prepare("SELECT S.*, A.username, A.realname, SC.name as categoryName FROM Supports S INNER JOIN Accounts A ON S.accountID = A.id INNER JOIN SupportCategories SC ON S.categoryID = SC.id WHERE S.id = ? AND S.accountID = ?");
		    $ticket->execute(array($id, auth()->user()->id()));
		    $ticket = $ticket->fetch();

        if (!$ticket) abort_404();
	    
		    SeoService::set('support.tickets.show', [
			    'ticket_title' => $ticket['title'],
		    ]);

        $updateTicketReadStatus = db()->prepare("UPDATE Supports SET readStatus = ? WHERE id = ? AND accountID = ?");
		    $updateTicketReadStatus->execute(array(1, $id, auth()->user()->id()));

        $supportMessages = db()->prepare("SELECT SM.*, A.username, A.realname FROM SupportMessages SM INNER JOIN Accounts A ON SM.accountID = A.id WHERE SM.supportID = ? ORDER BY SM.creationDate ASC");
        $supportMessages->execute(array($id));
	      $converter = new GithubFlavoredMarkdownConverter();
        $ticket["messages"] = array_map(function ($message) use ($converter, $ticket) {
	        if ($message["writeLocation"] == 1) {
		        $message["content"] = $converter->convertToHtml($message["message"]);
	        }
	        else {
		        $search = array("%username%", "%message%", "%servername%", "%serverip%", "%serverversion%");
		        $replace = array($ticket["realname"], $message["message"], settings('serverName'), settings('serverIP'), settings('serverVersion'));
		        $template = settings('supportMessageTemplate');
		        $message["content"] = str_replace($search, $replace, $template);
	        }
	        $message["user"] = [
						'id' => $message['accountID'],
            'username' => $message['username'],
            'displayName' => $message['realname'],
            'avatar' => AvatarService::get($message['accountID'], $message['realname']),
	        ];
					
					return $message;
        }, $supportMessages->fetchAll());

        $supportFieldValues = db()->prepare("SELECT CSFV.value, CSV.field FROM CustomSupportFieldValues CSFV INNER JOIN CustomSupportFields CSV ON CSV.id = CSFV.fieldID WHERE CSFV.supportID = ?");
        $supportFieldValues->execute(array($ticket["id"]));
		    $ticket["fields"] = $supportFieldValues->fetchAll();

        return $this->view('tickets.show', compact('ticket'));
    }

    public function destroy($id)
    {
        /*$deleteSupports = db()->prepare("DELETE FROM Supports WHERE id = ? AND accountID = ?");
        $deleteSupports->execute(array($id, auth()->user()->id()));

        redirect(url("support.tickets.index"));*/
    }

    public function reply($id)
    {
        $support = db()->prepare("SELECT S.*, A.username, A.realname, SC.name as categoryName FROM Supports S INNER JOIN Accounts A ON S.accountID = A.id INNER JOIN SupportCategories SC ON S.categoryID = SC.id WHERE S.id = ? AND S.accountID = ?");
        $support->execute(array($id, auth()->user()->id()));
        $support = $support->fetch();

        if (!$support) abort_404();
				
				if ($support["statusID"] == 4) {
					return back()->flash('error', t__("The ticket is closed. You can't send a message."));
				}

        validate([
            "message" => "required"
        ]);
				
				if (recaptcha()->isEnabled('reply_ticket') && !recaptcha()->verify()) {
						return back()->flash('error', t__('Spam detected!'));
				}

        $supportBannedStatus = db()->prepare("SELECT * FROM BannedAccounts WHERE accountID = ? AND categoryID = ? AND (expiryDate > ? OR expiryDate = ?)");
        $supportBannedStatus->execute(array(auth()->user()->id(), 2, datetime(), '1000-01-01 00:00:00'));
        $supportBannedStatus = $supportBannedStatus->fetch();

        if ($supportBannedStatus) {
            return back()->flash('error', t__('You are banned from support!'));
        }

        $insertSupportMessages = db()->prepare("INSERT INTO SupportMessages (accountID, message, supportID, writeLocation, creationDate) VALUES (?, ?, ?, ?, ?)");
        $insertSupportMessages->execute(array(auth()->user()->id(), input("message"), $support["id"], 1, datetime()));
        $updateSupports = db()->prepare("UPDATE Supports SET updateDate = ?, statusID = ?, readStatus = ? WHERE id = ? AND accountID = ?");
        $updateSupports->execute(array(datetime(), 3, 1, $support["id"], auth()->user()->id()));
        $insertNotifications = db()->prepare("INSERT INTO Notifications (accountID, type, variables, creationDate) VALUES (?, ?, ?, ?)");
        $insertNotifications->execute(array(auth()->user()->id(), 1, $support["id"], datetime()));

				DiscordWebhookService::send('support.ticket.replied', [
					"username" => auth()->user()->displayName(),
					"title" => $support["title"],
					"category" => $support["categoryName"],
					"message" => input("message"),
					"url" => website_url(url('support.tickets.show', ['id' => $support["id"]])),
					"dashboard_url" => website_url('/dashboard/support/tickets/' . $support["id"]),
				]);

        if (modules('discord')->isActive() && settings("discordTicketStatus") == '1' && $support["discordChannelID"] != null) {
            $discord = new Discord(settings("discordClientID"), settings("discordClientSecret"), settings("discordBotToken"));
            $discord->sendTicketMessage($support["discordChannelID"], auth()->user()->id(), auth()->user()->displayName(), input("message"));
        }

        return back()->flash('success', t__('Your message has been sent to us successfully. It will be answered by the staff as soon as possible.'));
    }

    public function close($id)
    {
        $closeSupport = db()->prepare("UPDATE Supports SET statusID = ? WHERE id = ? AND accountID = ?");
        $closeSupport->execute(array(4, $id, auth()->user()->id()));

        redirect(url("support.tickets.index"));
    }
		
		public function upload()
		{
			try {
				$image = CkEditorImageUploadService::upload($_FILES["upload"], "/apps/main/public/images/support/uploads/");
				response()->json([
					'url' => '/assets/core/images/support/uploads/' . $image,
				]);
			} catch (Exception $e) {
				response()->json([
					'status' => false,
					'error'  => $e->getMessage(),
				]);
			}
		}
}