<?php
	namespace Main\Services;
	
	use Exception;
	use Main\Libs\Parasut;
	
	class ParasutService
	{
		/**
		 * @throws Exception
		 */
		public static function createInvoice($orderID)
		{
			// Get Order
			$order = db()->prepare("SELECT * FROM Orders WHERE id = ?");
			$order->execute(array($orderID));
			$order = $order->fetch();
			if (!$order)
				throw new Exception("Order not found");
			
			$accountID = $order["accountID"];
			
			$parasut = new Parasut(settings('parasutClientID'), settings('parasutClientSecret'), settings('parasutCompanyID'));
			
			$accessToken = settings('parasutAccessToken');
			$refreshToken = settings('parasutRefreshToken');
			$expiryDate = settings('parasutTokenExpiryDate');

			// Refresh Token
			if ($expiryDate <= datetime()) {
				try {
					$refreshTokenResponse = $parasut->refreshAccessToken(settings('parasutRefreshToken'));
					$accessToken = $refreshTokenResponse->access_token;
					$refreshToken = $refreshTokenResponse->refresh_token;
					$expiryDate = date('Y-m-d H:i:s', time() + $refreshTokenResponse->expires_in);
					
					$updateSettings = db()->prepare("UPDATE Settings SET value = ? WHERE name = ?");
					$updateSettings->execute(array($accessToken, "parasutAccessToken"));
					$updateSettings->execute(array($refreshToken, "parasutRefreshToken"));
					$updateSettings->execute(array($expiryDate, "parasutTokenExpiryDate"));
				} catch (Exception $e) {
					throw new Exception("Refresh Token failed");
				}
			}

			// Get Customer
			$user = db()->prepare("SELECT A.id, A.email, ACI.* FROM Accounts A INNER JOIN AccountContactInfo ACI ON A.id = ACI.accountID WHERE A.id = ?");
			$user->execute(array($accountID));
			$user = $user->fetch();
			if (!$user)
				throw new Exception("User not found");
			
			$parasutCustomer = db()->prepare("SELECT * FROM AccountParasutData WHERE accountID = ?");
			$parasutCustomer->execute(array($accountID));
			$parasutCustomer = $parasutCustomer->fetch();
			
			if (!$parasutCustomer) {
				// If customer not found, create a new one
				$parasutCustomerQuery = $parasut->createCustomer($accessToken, sprintf('%s %s', $user["firstName"], $user["lastName"]), $user["email"]);
				$parasutCustomerID = $parasutCustomerQuery->data->id;
				
				// Save Customer ID to database
				$createAccountParasutData = db()->prepare("INSERT INTO AccountParasutData (accountID, contactID) VALUES (?, ?)");
				$createAccountParasutData->execute(array($accountID, $parasutCustomerID));
			}
			else {
				// If customer found, get customer ID
				$parasutCustomerID = $parasutCustomer["contactID"];
			}

			// Create Invoice
			$invoice = $parasut->createInvoice(
				$accessToken,
				$parasutCustomerID,
				$order["id"],
				settings('parasutProductID'),
				$order["total"]
			);
			$invoiceID = $invoice->data->id;

			// Pay Invoice
			$payInvoice = $parasut->payInvoice(
				$accessToken,
				$invoiceID,
				settings('parasutAccountID'),
				$order["total"]
			);

			// Create E-Archive
			$createEArchive = $parasut->createEArchive(
				$accessToken,
				$invoiceID,
				$order["paymentAPI"]
			);
		}
	}