<?php
  namespace Main\Services;
  
  use PDO;
  use Verot\Upload\Upload;
  
  class UserService
  {
    public static function get($user)
    {
			if (!$user || $user == "") return false;
			
      if (is_numeric($user))
        $account = db()->prepare("SELECT * FROM Accounts WHERE id = ?");
      else
        $account = db()->prepare("SELECT * FROM Accounts WHERE realname = ?");

      $account->execute([$user]);
      if ($account->rowCount() === 0) return false;
      
      return $account->fetch(PDO::FETCH_ASSOC);
    }

    public static function getByDiscordUserID($discordUserID)
    {
      $account = db()->prepare("SELECT A.*, ADC.discordUserID FROM AccountDiscordData ADC INNER JOIN Accounts A ON A.id = ADC.accountID WHERE ADC.discordUserID = ?");
      $account->execute([$discordUserID]);
      if ($account->rowCount() === 0) return false;

      return $account->fetch(PDO::FETCH_ASSOC);
    }
		
		public static function getRoles($id): array
		{
			static $defaultRole = null;
			$roles = [];
			$accountRoles = db()->prepare("SELECT R.*, AR.expiryDate FROM AccountRoles AR INNER JOIN Roles R ON AR.roleID = R.id WHERE AR.accountID = ? AND (AR.expiryDate > ? OR AR.expiryDate = ?) ORDER BY R.priority DESC");
			$accountRoles->execute(array($id, datetime(), '1000-01-01 00:00:00'));
			if ($accountRoles->rowCount() > 0) {
				$roles = $accountRoles->fetchAll(PDO::FETCH_ASSOC);
			}
			else {
				if ($defaultRole == null) {
					$defaultRole = db()->prepare("SELECT * FROM Roles WHERE slug = ?");
					$defaultRole->execute(array('default'));
					$defaultRole = $defaultRole->fetch(PDO::FETCH_ASSOC);
				}
				return [ $defaultRole ];
			}
			return $roles;
		}
		
		public static function getPermissions($id): array
		{
			$permissions = [];
			
			$roles = db()->prepare("SELECT * FROM AccountRoles WHERE accountID = ? AND (expiryDate > ? OR expiryDate = ?)");
			$roles->execute(array($id, datetime(), '1000-01-01 00:00:00'));
			$roles = $roles->fetchAll(PDO::FETCH_ASSOC);
			
			$rolePermissionsQuery = db()->prepare("SELECT P.id, P.name FROM RolePermissions RP INNER JOIN Permissions P ON P.id = RP.permissionID WHERE RP.roleID = ?");
			foreach ($roles as $role) {
				$rolePermissionsQuery->execute(array($role["roleID"]));
				$rolePermissions = $rolePermissionsQuery->fetchAll(PDO::FETCH_ASSOC);
				foreach ($rolePermissions as $rolePermission) {
					$permissions[] = $rolePermission["name"];
				}
			}
			$extraPermissions = db()->prepare("SELECT P.id, P.name FROM AccountPermissions AP INNER JOIN Permissions P ON P.id = AP.permissionID WHERE AP.accountID = ?");
			$extraPermissions->execute(array($id));
			$extraPermissions = $extraPermissions->fetchAll(PDO::FETCH_ASSOC);
			foreach ($extraPermissions as $extraPermission) {
				$permissions[] = $extraPermission["name"];
			}
			
			return $permissions;
		}
		
		public static function getSupportPermissions($id): array
		{
			$permissions = [];
			
			$permissions['STRICT_MANAGE_SUPPORT_TICKETS'] = false;
			
			$roles = db()->prepare("SELECT * FROM AccountRoles WHERE accountID = ? AND (expiryDate > ? OR expiryDate = ?)");
			$roles->execute(array($id, datetime(), '1000-01-01 00:00:00'));
			$roles = $roles->fetchAll(PDO::FETCH_ASSOC);
			
			$rolePermissionsQuery = db()->prepare("SELECT P.id, P.name, RP.categoryID FROM SupportCategoryRolePermissions RP INNER JOIN SupportCategoryPermissions P ON P.id = RP.permissionID WHERE RP.roleID = ?");
			foreach ($roles as $role) {
				$rolePermissionsQuery->execute(array($role["roleID"]));
				$rolePermissions = $rolePermissionsQuery->fetchAll(PDO::FETCH_ASSOC);
				foreach ($rolePermissions as $rolePermission) {
					$permissions[$rolePermission["name"]][] = $rolePermission["categoryID"];
				}
			}
			$extraPermissions = db()->prepare("SELECT P.id, P.name FROM AccountPermissions AP INNER JOIN Permissions P ON P.id = AP.permissionID WHERE AP.accountID = ? AND P.name = ? LIMIT 1");
			$extraPermissions->execute(array($id, 'MANAGE_SUPPORT_TICKETS'));
			$extraPermissions = $extraPermissions->fetch(PDO::FETCH_ASSOC);
			if ($extraPermissions) {
				$permissions['STRICT_MANAGE_SUPPORT_TICKETS'] = true;
			}
			
			return $permissions;
		}
		
		public static function isStaff($permissions): bool
		{
			return in_array('SUPER_ADMIN', $permissions) || in_array('VIEW_DASHBOARD', $permissions);
		}
		
		public static function uploadAvatarFromUrl($userID, $url)
		{
			// Get the avatar from link
			$avatarData = file_get_contents($url);
			
			$upload = new Upload('data:' . $avatarData);
			$imageID = md5(uniqid(rand(0, 9999999)));
			if ($upload->uploaded) {
				$upload->allowed = ["image/png", "image/gif", "image/jpg", "image/jpeg"];
				$upload->file_new_name_body = $imageID;
				$upload->image_resize = true;
				$upload->image_ratio_crop = true;
				$upload->image_x = 256;
				$upload->image_y = 256;
				$upload->process(__ROOT__ . "/apps/main/public/images/avatars/");
				if ($upload->processed) {
					$imageType = $upload->file_dst_name_ext;
					
					$checkAvatar = db()->prepare("SELECT * FROM Avatars WHERE accountID = ?");
					$checkAvatar->execute(array($userID));
					$checkAvatar = $checkAvatar->fetch();
					
					if ($checkAvatar) {
						$deleteAvatar = db()->prepare("DELETE FROM Avatars WHERE accountID = ?");
						$deleteAvatar->execute(array($userID));
						@unlink(__ROOT__ . "/apps/main/public/images/avatars/" . $checkAvatar["imageID"] . "." . $checkAvatar["imageType"]);
					}
					
					$insertAvatar = db()->prepare("INSERT INTO Avatars (accountID, imageID, imageType) VALUES (?, ?, ?)");
					$insertAvatar->execute(array($userID, $imageID, $imageType));
				}
			}
		}
  }